@@ -1,6 +1,6 @@
 # Copyright 1999-2004 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/rc-scripts/init.d/halt.sh,v 1.64 2004/12/04 03:48:34 vapier Exp $
+# $Header: /var/cvsroot/gentoo-src/rc-scripts/init.d/halt.sh,v 1.64.2.2 2004/12/15 20:00:34 vapier Exp $
 
 # Check to see if this is a livecd, if it is read the commandline
 # this mainly makes sure $CDBOOT is defined if it's a livecd
@@ -25,9 +25,9 @@ elif [ ! -e /dev/.devfsd -a -e /dev/.udev \
 then
 	ebegin "Saving device nodes"
 	# Handle our temp files
-	devices_udev="`mktemp /tmp/devices.udev.XXXXXX`"
-	devices_real="`mktemp /tmp/devices.real.XXXXXX`"
-	device_tarball="`mktemp /tmp/devices-XXXXXX`"
+	devices_udev="$(mktemp /tmp/devices.udev.XXXXXX)"
+	devices_real="$(mktemp /tmp/devices.real.XXXXXX)"
+	device_tarball="$(mktemp /tmp/devices-XXXXXX)"
 	
 	if [ -z "${devices_udev}" -o -z "${devices_real}" -o \
 	     -z "${device_tarball}" ]
@@ -39,18 +39,39 @@ then
 		find . -xdev -type b -or -type c -or -type l | cut -d/ -f2- > \
 			"${devices_real}"
 		# Figure out what udev created
-		udevinfo -d | awk '/^N|S: ..*/ { i=1; while (i++<NF) { print $i}}' > \
-			"${devices_udev}"
+		eval $(grep '^[[:space:]]*udev_db=' /etc/udev/udev.conf)
+		if [ -d "${udev_db}" ]
+		then
+			# New udev_db is clear text ...
+			udevinfo="$(cat "${udev_db}"/*)"
+		else
+			# Old one is not ...
+			udevinfo="$(udevinfo -d)"
+		fi
+		# This basically strips 'S:' and 'N:' from the db output, and then
+		# print all the nodes/symlinks udev created ...
+		echo "${udevinfo}" | gawk '
+			/^(N|S):.+/ {
+				sub(/^(N|S):/, "")
+				split($0, nodes)
+				for (x in nodes)
+					print nodes[x]
+			}' > "${devices_udev}"
 		# These ones we also do not want in there
-		for x in MAKEDEV core fd initctl pts shm sndstat stderr stdin stdout
+		for x in MAKEDEV core fd initctl pts shm stderr stdin stdout
 		do
 			echo "${x}" >> "${devices_udev}"
 		done
-		# Now only tarball those not created by udev
-		try tar -jclpf "${device_tarball}" \
-		        `fgrep -x -v -f "${devices_udev}" < "${devices_real}"`
-		try mv -f "${device_tarball}" /lib/udev-state/devices.tar.bz2
-		try rm -f "${devices_udev}" "${devices_real}"
+		tarball_devices="$(fgrep -x -v -f "${devices_udev}" < "${devices_real}")"
+		# Now only tarball those not created by udev if we have any
+		if [ -n "${tarball_devices}" ]
+		then
+			try tar -jclpf "${device_tarball}" ${tarball_devices}
+			try mv -f "${device_tarball}" /lib/udev-state/devices.tar.bz2
+			try rm -f "${devices_udev}" "${devices_real}"
+		else
+			rm -f /lib/udev-state/devices.tar.bz2
+		fi
 		eend 0
 	fi
 fi
