@@ -1,6 +1,6 @@
 # Copyright 1999-2004 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/functions.sh,v 1.81 2004/12/03 03:56:17 vapier Exp $
+# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/functions.sh,v 1.81.2.2 2004/12/10 15:27:45 vapier Exp $
 
 RC_GOT_FUNCTIONS="yes"
 
@@ -636,14 +636,19 @@ is_uml_sys() {
 	return $?
 }
 
-# bool is_in_fstab(path)
+# bool get_mount_fstab(path)
 #
-#   return 0 if path is listed in /etc/fstab
+#   return the parameters to pass to the mount command generated from fstab
 #
-#   EXAMPLE:  if is_in_fstab /proc ; then ...
+#   EXAMPLE: cmd=$( get_mount_fstab /proc )
+#            cmd=${cmd:--t proc none /proc}
+#            mount -n ${cmd}
 #
-is_in_fstab() {
-	[ -n "$(awk '($2 ~ /^'${*//\//\\/}'$/) { print }' /etc/fstab)" ]
+get_mount_fstab() {
+	awk '$1 ~ "^#" { next }
+	     $2 == "'$*'" { if (found++ == 0) { print "-t "$3,"-o "$4,$1,$2 } }
+	     END { if (found > 1) { print "More than one entry for '$*' found in /etc/fstab!" > "/dev/stderr" } }
+	' /etc/fstab
 }
 
 # bool is_older_than(reference, files/dirs to check)
