@@ -1,6 +1,6 @@
-# Copyright 1999-2004 Gentoo Technologies, Inc.
+# Copyright 1999-2004 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/rc-services.sh,v 1.17 2004/08/18 20:35:37 agriffis Exp $
+# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/rc-services.sh,v 1.20 2004/10/31 12:26:32 azarah Exp $
 
 # RC Dependency and misc service functions
 
@@ -434,7 +434,7 @@ stop_service() {
 	
 	[ -z "$1" ] && return 1
 
-	if service_started "$1" 
+	if service_started "$1"
 	then
 		splash "svc_stop" "$1"
 			
@@ -556,6 +556,39 @@ net_service() {
 	return 0
 }
 
+# bool is_net_up()
+#
+#    Return true if service 'net' is considered up, else false.
+#
+#    Notes for RC_NET_STRICT_CHECKING values:
+#      lo    Interface 'lo' is counted and if only it is up, net is up.
+#      no    Interface 'lo' is not counted, and net is down even with it up,
+#            so there have to be at least one other interface up.
+#      yes   All interfaces must be up.
+is_net_up() {
+	local netcount=0
+
+	case "${RC_NET_STRICT_CHECKING}" in
+		lo)
+			netcount="$(ls -1 "${svcdir}"/started/net.* 2> /dev/null | \
+			            egrep -c "\/net\..*$")"
+			;;
+		*)
+			netcount="$(ls -1 "${svcdir}"/started/net.* 2> /dev/null | \
+			            grep -v 'net\.lo' | egrep -c "\/net\..*$")"
+			;;
+	esac
+
+	# Only worry about net.* services if this is the last one running,
+	# or if RC_NET_STRICT_CHECKING is set ...
+	if [ "${netcount}" -lt 1 -o "${RC_NET_STRICT_CHECKING}" = "yes" ]
+	then
+		return 1
+	fi
+
+	return 0
+}
+
 # void schedule_service_startup(service)
 #
 #   Schedule 'service' for startup, in parallel if possible.
