@@ -1,7 +1,7 @@
 #!/bin/bash
 # Copyright 1999-2004 Gentoo Foundation
 # Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/runscript.sh,v 1.43 2004/11/15 18:02:57 vapier Exp $
+# $Header: /var/cvsroot/gentoo-src/rc-scripts/sbin/runscript.sh,v 1.44 2004/12/04 07:10:07 vapier Exp $
 
 # Common functions
 [ "${RC_GOT_FUNCTIONS}" != "yes" ] && source /sbin/functions.sh
@@ -16,11 +16,6 @@ if [[ ${EUID} != 0 ]] ; then
 	exit 1
 fi
 
-if [[ "${0##*/}" = "runscript.sh" ]] ; then
-	eerror "$0: Do not run this directly"
-	exit 1
-fi
-
 # State variables
 svcpause="no"
 svcrestart="no"
